import request from '@/utils/request'

// // 查询宠物档案列表
// export function listPmsPet(query) {
//   return request({
//     url: '/ums/pet/list',
//     method: 'get',
//     params: query
//   })
// }

// 查询宠物档案列表
export function listPmsPet(query, pageReq) {
  return request({
    url: '/ums/pet/list',
    method: 'post',
    data: query,
    params: pageReq
  })
}

// 查询宠物档案详细
export function getPmsPet(id) {
  return request({
    url: '/ums/pet/' + id,
    method: 'get'
  })
}

// 新增宠物档案
export function addPmsPet(data) {
  return request({
    url: '/ums/pet',
    method: 'post',
    data: data
  })
}

// 修改宠物档案
export function updatePmsPet(data) {
  return request({
    url: '/ums/pet',
    method: 'put',
    data: data
  })
}

// 删除宠物档案
export function delPmsPet(id) {
  return request({
    url: '/ums/pet/' + id,
    method: 'delete'
  })
}

// 导出宠物档案
export function exportPmsPet(query) {
  return request({
    url: '/ums/pet/export',
    method: 'get',
    params: query
  })
}
